DvG_QDeviceIO
=============

*Hassle-free PyQt5 interface for multithreaded data acquisition and communication with an I/O device.*


.. toctree::
   :caption: Introduction

   intro
   usage
   example


.. toctree::
   :caption: API

   api-qdeviceio
   api-workerdaq
   api-workerjobs
   api-daqtrigger
   └ INTERNAL_TIMER <api-daqtrigger-internaltimer>
   └ SINGLE_SHOT_WAKE_UP <api-daqtrigger-singleshotwakeup>
   └ CONTINUOUS <api-daqtrigger-continuous>


.. toctree::
   :maxdepth: 1
   :caption: Other
   
   notes
   authors
   changelog
   contributing
   genindex
